context_internal2!() { /* proc-macro */ }Expand description
Macro used by always_context attribute macro
Since it needs to provide the current line by itself
context_internal2!() { /* proc-macro */ }Macro used by always_context attribute macro
Since it needs to provide the current line by itself